@@ -1,5 +1,5 @@
 /*
- * Copyright (C) 2008-2024 Ole André Vadla Ravnås <oleavr@nowsecure.com>
+ * Copyright (C) 2008-2025 Ole André Vadla Ravnås <oleavr@nowsecure.com>
  * Copyright (C) 2023 Stefano Moioli <smxdev4@gmail.com>
  * Copyright (C) 2024 Yannis Juglaret <yjuglaret@mozilla.com>
  *
@@ -854,7 +854,7 @@ gum_do_query_cpu_features (void)
   GumDarwinAllImageInfos infos;
   GumDarwinCpuSubtype subtype;
 
-  gum_darwin_query_all_image_infos (mach_task_self (), &infos);
+  gum_darwin_query_all_image_infos (mach_task_self (), &infos, NULL);
 
   subtype = *((GumDarwinCpuSubtype *) (infos.dyld_image_load_address + 8));
   if ((subtype & GUM_DARWIN_CPU_SUBTYPE_MASK) == GUM_DARWIN_CPU_SUBTYPE_ARM64E)
